You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@ignite.apache.org by av...@apache.org on 2021/03/26 08:08:29 UTC

[ignite] branch ignite-ducktape updated: IGNITE-14396: Сrash of snapshot test on ducktape (#8930)

This is an automated email from the ASF dual-hosted git repository.

av pushed a commit to branch ignite-ducktape
in repository https://gitbox.apache.org/repos/asf/ignite.git


The following commit(s) were added to refs/heads/ignite-ducktape by this push:
     new c626d9d  IGNITE-14396: Сrash of snapshot test on ducktape (#8930)
c626d9d is described below

commit c626d9d19aab9d22023424912d32670005458c93
Author: Sergei Ryzhov <s....@gmail.com>
AuthorDate: Fri Mar 26 11:08:15 2021 +0300

    IGNITE-14396: Сrash of snapshot test on ducktape (#8930)
---
 modules/ducktests/tests/ignitetest/__init__.py                    | 4 ++--
 .../ducktests/tests/ignitetest/services/utils/control_utility.py  | 8 +++++++-
 modules/ducktests/tests/ignitetest/utils/version.py               | 5 +++++
 3 files changed, 14 insertions(+), 3 deletions(-)

diff --git a/modules/ducktests/tests/ignitetest/services/utils/control_utility.py b/modules/ducktests/tests/ignitetest/services/utils/control_utility.py
index 1744195..7c3249b 100644
--- a/modules/ducktests/tests/ignitetest/services/utils/control_utility.py
+++ b/modules/ducktests/tests/ignitetest/services/utils/control_utility.py
@@ -28,6 +28,7 @@ from ducktape.cluster.remoteaccount import RemoteCommandError
 from ignitetest.services.utils.auth import get_credentials, is_auth_enabled
 from ignitetest.services.utils.ssl.ssl_params import get_ssl_params, is_ssl_enabled, IGNITE_ADMIN_ALIAS
 from ignitetest.services.utils.jmx_utils import JmxClient
+from ignitetest.utils.version import V_2_11_0
 
 
 class ControlUtility:
@@ -157,7 +158,12 @@ class ControlUtility:
         """
         data = self.__run("--cache idle_verify")
 
-        assert ('idle_verify check has finished, no conflicts have been found.' in data), data
+        if self._cluster.config.version < V_2_11_0:
+            msg = 'idle_verify check has finished, no conflicts have been found.'
+        else:
+            msg = 'The check procedure has finished, no conflicts have been found.'
+
+        assert (msg in data), data
 
     def idle_verify_dump(self, node=None):
         """
diff --git a/modules/ducktests/tests/ignitetest/utils/version.py b/modules/ducktests/tests/ignitetest/utils/version.py
index abae5c2..6f7e333 100644
--- a/modules/ducktests/tests/ignitetest/utils/version.py
+++ b/modules/ducktests/tests/ignitetest/utils/version.py
@@ -76,4 +76,9 @@ LATEST_2_9 = V_2_9_1
 V_2_10_0 = IgniteVersion("2.10.0")
 LATEST_2_10 = V_2_10_0
 
+# 2.11.x versions
+V_2_11_0 = IgniteVersion("2.11.0")
+
+# if you updated the LATEST version
+# please check DEV version in 'tests/ignitetest/__init__.py'
 LATEST = LATEST_2_10
diff --git a/modules/ducktests/tests/ignitetest/__init__.py b/modules/ducktests/tests/ignitetest/__init__.py
index 8cbaed8..17b0e62 100644
--- a/modules/ducktests/tests/ignitetest/__init__.py
+++ b/modules/ducktests/tests/ignitetest/__init__.py
@@ -22,5 +22,5 @@
 #
 # Instead, in development branches, the version should have a suffix of the form ".devN"
 #
-# For example, when Ignite is at version 2.9.0-SNAPSHOT, this should be something like "2.9.0.dev0"
-__version__ = '2.10.0.dev0'
+# For example, when Ignite is at version 2.9.0-SNAPSHOT, this should be something like "2.9.0-dev"
+__version__ = '2.11.0-dev'